<?php
namespace plugins\blog\controllers;

/**
 * Settings controller
 * @author Jérôme Brilland
 * @version 2.1
 * @copyright (c) 2021-2022, Jérôme Brilland
 * @license http://www.gnu.org/licenses/gpl.txt GNU General Public License
 */
class SettingsController extends \ActionController {

    protected function beforeFilter() {
        $authorization = \IoC::resolve( 'authorization' );
        $authorization->authorize( 'manage_settings' );
    }

    public function doIndex() {
        $settings = \IoC::resolve( 'settings' );
        $i18n =  \IoC::resolve( 'i18n' );
        $this->title = $i18n->__( 'settings' );
        $this->postsPerPage = $settings['blog.posts_per_page'];
        $this->moderateComments = $settings['blog.moderate_comments'];
        $this->spamKeywords = $settings['blog.spam_keywords'];
        $this->render( 'settingsform.html' );
    }

    public function doUpdate() {
        $configurationHandler = \IoC::resolve( 'databaseConfigurationHandler' );
        $settings = new \Configuration( $configurationHandler );
        $settings['blog.posts_per_page'] = $this->request->getParameters()->getInt( 'blog_posts_per_page' );
        $settings['blog.moderate_comments'] = $this->request->getParameters()->getInt( 'blog_moderate_comments' );
        $settings['blog.spam_keywords'] = $this->request->getParameter( 'blog_spam_keywords' );
        $configurationHandler->save();
        $this->flash['success'] = \IoC::resolve( 'i18n' )->__( 'settings_successfully_updated' );
        $this->redirect( BASE_URL . 'blog/settings' );
    }
}
